@@ -70,6 +70,8 @@ static struct bool_opts {
 	{"noac", ~NFS_MOUNT_NOAC, NFS_MOUNT_NOAC},
 	{"lock", ~NFS_MOUNT_NONLM, 0},
 	{"nolock", ~NFS_MOUNT_NONLM, NFS_MOUNT_NONLM},
+	{"acl", ~NFS_MOUNT_NOACL, 0},
+	{"noacl", ~NFS_MOUNT_NOACL, NFS_MOUNT_NOACL},
 	{"v2", ~NFS_MOUNT_VER3, 0},
 	{"v3", ~NFS_MOUNT_VER3, NFS_MOUNT_VER3},
 	{"udp", ~NFS_MOUNT_TCP, 0},
@@ -165,7 +167,7 @@ int nfsmount_main(int argc, char *argv[])
 	int c;
 	const char *portmap_file;
 	pid_t spoof_portmap;
-	int err;
+	int err, ret;
 
 	if ((err = setjmp(abort_buf)))
 		return err;
@@ -241,13 +243,14 @@ int nfsmount_main(int argc, char *argv[])
 		return 1;
 #endif
 
+	ret = 0;
 	if (nfs_mount(rem_name, hostname, server, rem_path, path,
 		      &mount_data) != 0)
-		return 1;
+		ret = 1;
 
 	/* If we set up the spoofer, tear it down now */
 	if (spoof_portmap) {
-		kill(SIGTERM, spoof_portmap);
+		kill(spoof_portmap, SIGTERM);
 		while (waitpid(spoof_portmap, NULL, 0) == -1 &&
 		       errno == EINTR)
 		  ;
@@ -255,5 +258,5 @@ int nfsmount_main(int argc, char *argv[])
 
 	free(rem_name);
 
-	return 0;
+	return ret;
 }
