@@ -1,12 +1,14 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/stat.h>
 
 char *progname;
 
 static __noreturn usage(void)
 {
-	fprintf(stderr, "Usage: %s name {b|c|p} major minor\n", progname);
+	fprintf(stderr, "Usage: %s [-m mode] name {b|c|p} major minor\n",
+			progname);
 	exit(1);
 }
 
@@ -14,11 +16,16 @@ int main(int argc, char *argv[])
 {
 	char *name, *type, typec, *endp;
 	unsigned int major_num, minor_num;
-	mode_t mode;
+	mode_t mode, mode_set = 0;
 	dev_t dev;
 
 	progname = *argv++;
 
+	if (argv[0][0] == '-' && argv[0][1] == 'm' && !argv[0][2]) {
+		mode_set = strtoul(argv[1], &endp, 8);
+		argv += 2;
+	}
+
 	name = *argv++;
 	if (!name)
 		usage();
@@ -66,5 +73,10 @@ int main(int argc, char *argv[])
 		exit(1);
 	}
 
+	if (mode_set && chmod(name, mode_set)) {
+		perror("chmod");
+		exit(1);
+	}
+
 	exit(0);
 }
